@@ -4,16 +4,14 @@ Main interface for appflow service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_appflow import (
         AppflowClient,
         Client,
     )
 
-    session = boto3.Session()
-
-    client: AppflowClient = boto3.client("appflow")
-    session_client: AppflowClient = session.client("appflow")
+    session = Session()
+    client: AppflowClient = session.client("appflow")
     ```
 """
 from .client import AppflowClient
