@@ -57,7 +57,9 @@ __all__ = (
     "VeevaConnectorOperatorType",
     "WriteOperationTypeType",
     "ZendeskConnectorOperatorType",
+    "AppflowServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -425,6 +427,7 @@ ZendeskConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+AppflowServiceName = Literal["appflow"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -456,6 +459,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -727,3 +731,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
